<?php

namespace Drupal\entity_reference_current_language\Plugin\EntityReferenceSelection;

use Drupal\Core\Entity\Plugin\EntityReferenceSelection\DefaultSelection;
use Drupal\Core\Form\FormStateInterface;

/**
 * Filters entity reference selections by the current language.
 *
 * @EntityReferenceSelection(
 *   id = "current_language",
 *   label = @Translation("Current Language"),
 *   group = "current_language",
 *   weight = 0
 * )
 */
class CurrentLanguageSelection extends DefaultSelection {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);
    $form['current_language'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Filter by current language'),
      '#default_value' => $this->configuration['current_language'] ?? TRUE,
      '#description' => $this->t('If checked, only content in the current language will be available for selection.'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  protected function buildEntityQuery($match = NULL, $match_operator = 'CONTAINS') {
    $query = parent::buildEntityQuery($match, $match_operator);

    if (!empty($this->configuration['current_language'])) {
      $query->condition('langcode', \Drupal::languageManager()->getCurrentLanguage()->getId());
    }

    return $query;
  }

}
